==> tecfy_core_package-1.1.19.tar.gz: lib/views/home/drawer3.dart <==
part of tecfy_core_client_package;

class MainDrawer3 extends StatefulWidget {
  final dynamic selected;
  MainDrawer3(this.selected);
  @override
  _MainDrawer3State createState() => _MainDrawer3State();
}

class _MainDrawer3State extends AppState<MainDrawer3> {
  // static double _posstion = 0;
  bool _isMobile = true;
  double? _topMargen;
  late ScrollController _controller;
  String? _selectedCategory;

  @override
  void initState() {
    _controller = ScrollController();

    // get category based on selected item
    if (InitService.menuItems != null && InitService.menuItems!.length > 0) {
      var selected = InitService.menuItems!.where((e) =>
          e.title == widget.selected ||
          (e.subMenuItems?.any((s) => s.title == widget.selected) ?? false));
      if (selected.length > 0) {
        _selectedCategory = selected.first.title;
      }
    }
    //_selectedCategory = widget.selected;

    // Future.delayed(Duration(milliseconds: 100)).then((_) {
    //   if (_controller.offset != _posstion) _controller.jumpTo(_posstion);
    //   _controller.addListener(() {
    //     _posstion = _controller.offset ?? 0;
    //   });
    // });
    super.initState();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  onItemClick(TecfyMenuItem itm) {
    if (itm.subMenuItems != null && itm.subMenuItems!.length > 0) {
      setState(() {
        _selectedCategory = itm.title;
      });
    }
    // if (itm.title != widget.selected) {
    // }

    itm.onClick?.call(context);
  }

  @override
  Widget build(BuildContext context) {
    _isMobile = LayoutService.isMobile(context);
    //_topMargen = _isMobile ? 30 : 0;
    _topMargen = MediaQuery.of(context).padding.top;
    return Drawer(
      child: Container(
          color: ThemeService.mainColor,
          child: Column(
            children: <Widget>[
              Container(
                // height: 300,
                child: Stack(
                  children: <Widget>[
                    Container(
                        height: 120 + (_topMargen ?? 0),
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.only(
                            bottomLeft: LocalConfigService.isArabic
                                ? Radius.circular(50)
                                : Radius.circular(0),
                            bottomRight: LocalConfigService.isArabic
                                ? Radius.circular(0)
                                : Radius.circular(50),
                          ),
                          color: ThemeService.secondryColor,
                        ),
                        child: !_isMobile
                            ? Align(
                                alignment: Alignment.bottomRight,
                                child: Padding(
                                    padding: EdgeInsets.only(
                                        right: 95, left: 0, bottom: 6),
                                    child: TextButton(
                                        child: Text(trans('الشاشة الرئيسية'),
                                            style: TextStyle(
                                                fontSize: 18,
                                                color: ThemeService
                                                    .textOnSecondColor)),
                                        onPressed: () =>
                                            AppNavigator.navigateTo(
                                                context, () => DashboardPage(),
                                                replaceAll: true))))
                            : Align(
                                alignment: Alignment.bottomCenter,
                                child: Padding(
                                    padding: EdgeInsets.only(
                                        right: LocalConfigService.isArabic
                                            ? 95
                                            : 0,
                                        left: LocalConfigService.isArabic
                                            ? 0
                                            : 95,
                                        bottom: 18),
                                    child: Row(
                                      children: <Widget>[
                                        Text(trans('Welcome'),
                                            style: TextStyle(
                                                color: ThemeService
                                                    .textOnSecondColor)),
                                        Text(',',
                                            style: TextStyle(
                                                color: ThemeService
                                                    .textOnSecondColor)),
                                        Text(
                                            LocalConfigService.user?.fullName ??
                                                trans("Guest"),
                                            textDirection: TextDirection.rtl,
                                            maxLines: 1,
                                            overflow: TextOverflow.fade,
                                            style: TextStyle(
                                                color: ThemeService
                                                    .textOnSecondColor,
                                                fontSize: 18))
                                      ],
                                    )))),
                    Container(
                        height: 60 + (_topMargen ?? 0),
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.only(
                            bottomLeft: LocalConfigService.isArabic
                                ? Radius.circular(50)
                                : Radius.circular(0),
                            bottomRight: LocalConfigService.isArabic
                                ? Radius.circular(0)
                                : Radius.circular(50),
                          ),
                          color: ThemeService.backgroundColor,
                        ),
                        child: !_isMobile
                            ? null
                            : Align(
                                alignment: Alignment.bottomCenter,
                                child: Row(
                                  mainAxisAlignment: MainAxisAlignment.end,
                                  children: <Widget>[
                                    SizedBox(width: 30),
                                    IconButton(
                                        tooltip: trans('Chat'),
                                        onPressed: () =>
                                            AppNavigator.navigateTo(context,
                                                () => ChatContactsPage()),
                                        icon: Icon(Icons.markunread,
                                            color: ThemeService.textSubColor)),
                                    SizedBox(width: 2),
                                    NotificationIcon(
                                        color: ThemeService.textSubColor),
                                    SizedBox(width: 2),
                                    IconButton(
                                        tooltip: trans('Settings'),
                                        icon: Icon(Icons.settings,
                                            color: ThemeService.textSubColor),
                                        onPressed: () {
                                          if (LayoutService.isMobile(context))
                                            Navigator.pop(context);
                                          // AppNavigator.navigateToNamed(
                                          //     context, '/setting');
                                          AppNavigator.showAppDialogEx(
                                              context, () => SettingPage(true),
                                              size: DialogBoxSizes.large,
                                              barrierDismissible: true,
                                              title: trans('Settings'));
                                        },
                                        padding: EdgeInsets.all(0)),
                                    SizedBox(width: 30),
                                  ],
                                ))),
                    Padding(
                        padding: EdgeInsets.only(
                            right: 10, left: 10, top: 10 + (_topMargen ?? 0)),
                        child: Container(
                            //color: Colors.white,
                            child: Icon(Icons.person, size: 40),
                            decoration: BoxDecoration(
                                //image: DecorationImage(image: TecfyCoreApp.logo.image,fit: BoxFit.scaleDown),
                                color: Colors.white,
                                shape: BoxShape.circle,
                                boxShadow: [
                                  BoxShadow(
                                      blurRadius: 20.0,
                                      offset: Offset(2, 2),
                                      spreadRadius: 2,
                                      color: Colors.black12)
                                ]),
                            width: 85,
                            height: 85)),
                  ],
                ),
              ),
              Expanded(
                child: ListView(
                    controller: _isMobile ? ScrollController() : _controller,
                    children: (InitService.menuItems ?? [])
                        .map<Widget>((c) => _selectedCategory == c.title
                            ? selectedMenuItemWidget(c)
                            : unselectedMenuItem(c))
                        .toList()),
              ),
              _isMobile
                  ? TextButton(
                      child: Text(trans('Logout'),
                          style: TextStyle(color: ThemeService.secondryColor)),
                      onPressed: () => AccountService.signout(context))
                  : Container(),
            ],
          )),
    );
  }

  selectedMenuItemWidget(TecfyMenuItem c) {
    return Container(
      margin: EdgeInsets.only(right: 10),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.only(
          bottomRight: Radius.circular(50),
          topRight: Radius.circular(50),
        ),
        color: Color.fromRGBO(73, 77, 89, 1),
      ),
      child: MaterialButton(
        onPressed: () => onItemClick(c),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: (c.subMenuItems ?? []) //
              .map<Widget>((sub) => Hero(
                  tag: sub.title == widget.selected
                      ? 'menuItem-selected'
                      : 'menuItem-${sub.title}',
                  child: MaterialButton(
                      onPressed: () => onItemClick(sub),
                      padding: EdgeInsets.only(
                          right: LocalConfigService.isArabic ? 70 : 0,
                          left: LocalConfigService.isArabic ? 0 : 70),
                      child: Align(
                          alignment: LocalConfigService.isArabic
                              ? Alignment.centerRight
                              : Alignment.centerLeft,
                          child: Text(sub.displayName,
                              style: TextStyle(
                                  fontWeight: sub.title == widget.selected
                                      ? FontWeight.w700
                                      : FontWeight.normal,
                                  decoration: sub.title == widget.selected
                                      ? TextDecoration.underline
                                      : TextDecoration.none,
                                  color: ThemeService.textOnMainColor))))))
              .toList()
            ..insert(
                0,
                Padding(
                    padding: EdgeInsets.only(
                        top: 10,
                        bottom: (c.subMenuItems ?? []).length == 0 ? 10 : 0),
                    child: selectedMenuItem(c))),
        ),
      ),
    );
  }

  selectedMenuItem(c) {
    return Row(
      children: <Widget>[
        SizedBox(width: 20),
        Container(
            decoration: BoxDecoration(
                color: ThemeService.secondryColor, shape: BoxShape.circle),
            width: 10,
            height: 10),
        SizedBox(width: 15),
        Text(trans(c.displayName),
            style: TextStyle(color: ThemeService.subColor, fontSize: 18))
      ],
    );
  }

  unselectedMenuItem(c) {
    return MaterialButton(
        onPressed: () => onItemClick(c),
        child: Row(
          children: <Widget>[
            SizedBox(width: 30),
            Container(
                decoration: BoxDecoration(
                    color: Color.fromRGBO(100, 104, 116, 1),
                    shape: BoxShape.circle),
                width: 10,
                height: 10),
            SizedBox(width: 15),
            Text(trans(c.displayName),
                style: TextStyle(
                    color: Color.fromRGBO(100, 104, 116, 1), fontSize: 18))
          ],
        ));
  }
}

==> tecfy_core_package-1.1.25.tar.gz: lib/views/home/drawer3.dart <==
part of tecfy_core_client_package;

class MainDrawer3 extends StatefulWidget {
  final dynamic selected;
  MainDrawer3(this.selected);
  @override
  _MainDrawer3State createState() => _MainDrawer3State();
}

class _MainDrawer3State extends AppState<MainDrawer3> {
  // static double _posstion = 0;
  bool _isMobile = true;
  double? _topMargen;
  late ScrollController _controller;
  String? _selectedCategory;

  @override
  void initState() {
    _controller = ScrollController();

    // get category based on selected item
    if (InitService.menuItems != null && InitService.menuItems!.length > 0) {
      var selected = InitService.menuItems!.where((e) =>
          e.title == widget.selected ||
          (e.subMenuItems?.any((s) => s.title == widget.selected) ?? false));
      if (selected.length > 0) {
        _selectedCategory = selected.first.title;
      }
    }
    //_selectedCategory = widget.selected;

    // Future.delayed(Duration(milliseconds: 100)).then((_) {
    //   if (_controller.offset != _posstion) _controller.jumpTo(_posstion);
    //   _controller.addListener(() {
    //     _posstion = _controller.offset ?? 0;
    //   });
    // });
    super.initState();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  onItemClick(TecfyMenuItem itm) {
    if (itm.subMenuItems != null && itm.subMenuItems!.length > 0) {
      setState(() {
        _selectedCategory = itm.title;
      });
    }
    // if (itm.title != widget.selected) {
    // }

    itm.onClick?.call(context);
  }

  @override
  Widget build(BuildContext context) {
    _isMobile = LayoutService.isMobile(context);
    //_topMargen = _isMobile ? 30 : 0;
    _topMargen = MediaQuery.of(context).padding.top;
    return Drawer(
      child: Container(
          color: ThemeService.mainColor,
          child: Column(
            children: <Widget>[
              Container(
                // height: 300,
                child: Stack(
                  children: <Widget>[
                    Container(
                        height: 120 + (_topMargen ?? 0),
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.only(
                            bottomLeft: LocalConfigService.isArabic
                                ? Radius.circular(50)
                                : Radius.circular(0),
                            bottomRight: LocalConfigService.isArabic
                                ? Radius.circular(0)
                                : Radius.circular(50),
                          ),
                          color: ThemeService.secondryColor,
                        ),
                        child: !_isMobile
                            ? Align(
                                alignment: Alignment.bottomRight,
                                child: Padding(
                                    padding: EdgeInsets.only(
                                        right: 95, left: 0, bottom: 6),
                                    child: TextButton(
                                        child: Text(trans('الشاشة الرئيسية'),
                                            style: TextStyle(
                                                fontSize: 18,
                                                color: ThemeService
                                                    .textOnSecondColor)),
                                        onPressed: () =>
                                            AppNavigator.navigateTo(
                                                context, () => DashboardPage(),
                                                replaceAll: true))))
                            : Align(
                                alignment: Alignment.bottomCenter,
                                child: Padding(
                                    padding: EdgeInsets.only(
                                        right: LocalConfigService.isArabic
                                            ? 95
                                            : 0,
                                        left: LocalConfigService.isArabic
                                            ? 0
                                            : 95,
                                        bottom: 18),
                                    child: Row(
                                      children: <Widget>[
                                        Text(trans('Welcome'),
                                            style: TextStyle(
                                                color: ThemeService
                                                    .textOnSecondColor)),
                                        Text(',',
                                            style: TextStyle(
                                                color: ThemeService
                                                    .textOnSecondColor)),
                                        Text(
                                            LocalConfigService.user?.fullName ??
                                                trans("Guest"),
                                            textDirection: TextDirection.rtl,
                                            maxLines: 1,
                                            overflow: TextOverflow.fade,
                                            style: TextStyle(
                                                color: ThemeService
                                                    .textOnSecondColor,
                                                fontSize: 18))
                                      ],
                                    )))),
                    Container(
                        height: 60 + (_topMargen ?? 0),
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.only(
                            bottomLeft: LocalConfigService.isArabic
                                ? Radius.circular(50)
                                : Radius.circular(0),
                            bottomRight: LocalConfigService.isArabic
                                ? Radius.circular(0)
                                : Radius.circular(50),
                          ),
                          color: ThemeService.backgroundColor,
                        ),
                        child: !_isMobile
                            ? null
                            : Align(
                                alignment: Alignment.bottomCenter,
                                child: Row(
                                  mainAxisAlignment: MainAxisAlignment.end,
                                  children: <Widget>[
                                    SizedBox(width: 30),
                                    IconButton(
                                        tooltip: trans('Chat'),
                                        onPressed: () =>
                                            AppNavigator.navigateTo(context,
                                                () => ChatContactsPage()),
                                        icon: Icon(Icons.markunread,
                                            color: ThemeService.textSubColor)),
                                    SizedBox(width: 2),
                                    NotificationIcon(
                                        color: ThemeService.textSubColor),
                                    SizedBox(width: 2),
                                    IconButton(
                                        tooltip: trans('Settings'),
                                        icon: Icon(Icons.settings,
                                            color: ThemeService.textSubColor),
                                        onPressed: () {
                                          if (LayoutService.isMobile(context))
                                            Navigator.pop(context);
                                          // AppNavigator.navigateToNamed(
                                          //     context, '/setting');
                                          AppNavigator.showAppDialogEx(
                                              context, () => SettingPage(true),
                                              size: DialogBoxSizes.large,
                                              barrierDismissible: true,
                                              title: trans('Settings'));
                                        },
                                        padding: EdgeInsets.all(0)),
                                    SizedBox(width: 30),
                                  ],
                                ))),
                    Padding(
                        padding: EdgeInsets.only(
                            right: 10, left: 10, top: 10 + (_topMargen ?? 0)),
                        child: Container(
                            //color: Colors.white,
                            child: Icon(Icons.person, size: 40),
                            decoration: BoxDecoration(
                                //image: DecorationImage(image: TecfyCoreApp.logo.image,fit: BoxFit.scaleDown),
                                color: Colors.white,
                                shape: BoxShape.circle,
                                boxShadow: [
                                  BoxShadow(
                                      blurRadius: 20.0,
                                      offset: Offset(2, 2),
                                      spreadRadius: 2,
                                      color: Colors.black12)
                                ]),
                            width: 85,
                            height: 85)),
                  ],
                ),
              ),
              Expanded(
                child: ListView(
                    controller: _isMobile ? ScrollController() : _controller,
                    children: (InitService.menuItems ?? [])
                        .map<Widget>((c) => _selectedCategory == c.title
                            ? selectedMenuItemWidget(c)
                            : unselectedMenuItem(c))
                        .toList()),
              ),
              _isMobile
                  ? TextButton(
                      child: Text(trans('Logout'),
                          style: TextStyle(color: ThemeService.secondryColor)),
                      onPressed: () => AccountService.signout(context))
                  : Container(),
            ],
          )),
    );
  }

  selectedMenuItemWidget(TecfyMenuItem c) {
    return Container(
      margin: EdgeInsets.only(right: 10),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.only(
          bottomRight: Radius.circular(50),
          topRight: Radius.circular(50),
        ),
        color: Color.fromRGBO(73, 77, 89, 1),
      ),
      child: MaterialButton(
        onPressed: () => onItemClick(c),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: (c.subMenuItems ?? []) //
              .map<Widget>((sub) => Hero(
                  tag: sub.title == widget.selected
                      ? 'menuItem-selected'
                      : 'menuItem-${sub.title}',
                  child: MaterialButton(
                      onPressed: () => onItemClick(sub),
                      padding: EdgeInsets.only(
                          right: LocalConfigService.isArabic ? 70 : 0,
                          left: LocalConfigService.isArabic ? 0 : 70),
                      child: Align(
                          alignment: LocalConfigService.isArabic
                              ? Alignment.centerRight
                              : Alignment.centerLeft,
                          child: Text(sub.displayName,
                              style: TextStyle(
                                  fontWeight: sub.title == widget.selected
                                      ? FontWeight.w700
                                      : FontWeight.normal,
                                  decoration: sub.title == widget.selected
                                      ? TextDecoration.underline
                                      : TextDecoration.none,
                                  color: ThemeService.textOnMainColor))))))
              .toList()
            ..insert(
                0,
                Padding(
                    padding: EdgeInsets.only(
                        top: 10,
                        bottom: (c.subMenuItems ?? []).length == 0 ? 10 : 0),
                    child: selectedMenuItem(c))),
        ),
      ),
    );
  }

  selectedMenuItem(c) {
    return Row(
      children: <Widget>[
        SizedBox(width: 20),
        Container(
            decoration: BoxDecoration(
                color: ThemeService.secondryColor, shape: BoxShape.circle),
            width: 10,
            height: 10),
        SizedBox(width: 15),
        TecfyText(trans(c.displayName),
            style: TextStyle(color: ThemeService.subColor, fontSize: 18))
      ],
    );
  }

  unselectedMenuItem(c) {
    return MaterialButton(
        onPressed: () => onItemClick(c),
        child: Row(
          children: <Widget>[
            SizedBox(width: 30),
            Container(
                decoration: BoxDecoration(
                    color: Color.fromRGBO(100, 104, 116, 1),
                    shape: BoxShape.circle),
                width: 10,
                height: 10),
            SizedBox(width: 15),
            TecfyText(trans(c.displayName),
                style: TextStyle(
                    color: Color.fromRGBO(100, 104, 116, 1), fontSize: 18))
          ],
        ));
  }
}
